@@ -616,12 +616,15 @@ void
 window_cmd_file_work_offline (GtkAction *action,
 		              EphyWindow *window)
 {
+        /* TODO: WebKitGTK+ does not currently support offline status. */
+#if 0
 	EphyEmbedSingle *single;
 	gboolean offline;
 
 	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
 	offline = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	ephy_embed_single_set_network_status (single, !offline);
+#endif
 }
 
 void
@@ -1102,19 +1105,6 @@ window_cmd_view_page_source (GtkAction *action,
 	}
 }
 
-void
-window_cmd_view_page_security_info (GtkAction *action,
-				    EphyWindow *window)
-{
-	EphyEmbed *embed;
-
-	embed = ephy_embed_container_get_active_child 
-          (EPHY_EMBED_CONTAINER (window));
-	g_return_if_fail (EPHY_IS_EMBED (embed));
-
-	ephy_web_view_show_page_certificate (ephy_embed_get_web_view (embed));
-}
-
 #define ABOUT_GROUP "About"
 
 void
